@@ -224,15 +224,16 @@ app.add_middleware(
 
 
 # API Key Authentication Dependency
-async def verify_api_key(request: Request) -> bool:
+def verify_api_key(request: Request) -> None:
     """
     Verify API key from request headers.
-    If LADDR_API_KEY is not set, authentication is disabled (returns True).
+    If LADDR_API_KEY is not set, authentication is disabled (no-op).
     If LADDR_API_KEY is set, validates the key from X-API-Key or Authorization header.
+    Raises HTTPException(401) if invalid or missing.
     """
     # If API key is not configured, skip authentication
     if not config.laddr_api_key:
-        return True
+        return
     
     # Extract API key from headers
     api_key = request.headers.get("X-API-Key")
@@ -248,13 +249,10 @@ async def verify_api_key(request: Request) -> bool:
             status_code=401,
             detail="Invalid or missing API key"
         )
-    
-    return True
 
 
-def require_api_key(request: Request = Depends(verify_api_key)) -> bool:
-    """Dependency to require API key authentication."""
-    return request
+# Alias for cleaner usage in route decorators
+require_api_key = Depends(verify_api_key)
 
 
 async def verify_websocket_api_key(websocket: WebSocket) -> None:
@@ -325,7 +323,7 @@ async def health():
 
 
 @app.post("/api/jobs")
-async def submit_job(request: SubmitJobRequest, _: bool = Depends(require_api_key)):
+async def submit_job(request: SubmitJobRequest, _: None = require_api_key):
     """
     Submit a new job for execution.
 
@@ -359,7 +357,7 @@ async def submit_job(request: SubmitJobRequest, _: bool = Depends(require_api_ke
 
 
 @app.get("/api/jobs/{job_id}")
-async def get_job(job_id: str, _: bool = Depends(require_api_key)):
+async def get_job(job_id: str, _: None = require_api_key):
     """
     Get job status and result.
 
@@ -402,7 +400,7 @@ async def get_job(job_id: str, _: bool = Depends(require_api_key)):
 
 
 @app.get("/api/jobs")
-async def list_jobs(limit: int = 50, offset: int = 0, _: bool = Depends(require_api_key)):
+async def list_jobs(limit: int = 50, offset: int = 0, _: None = require_api_key):
     """
     List recent jobs.
 
@@ -438,7 +436,7 @@ async def list_jobs(limit: int = 50, offset: int = 0, _: bool = Depends(require_
 
 
 @app.post("/api/jobs/{job_id}/replay")
-async def replay_job(job_id: str, request: ReplayJobRequest, _: bool = Depends(require_api_key)):
+async def replay_job(job_id: str, request: ReplayJobRequest, _: None = require_api_key):
     """
     Replay a previous job.
 
@@ -463,7 +461,7 @@ async def replay_job(job_id: str, request: ReplayJobRequest, _: bool = Depends(r
 # --- New Prompt Endpoints (preferred terminology) ---
 
 @app.post("/api/prompts")
-async def submit_prompt(request: SubmitPromptRequest, _: bool = Depends(require_api_key)):
+async def submit_prompt(request: SubmitPromptRequest, _: None = require_api_key):
     """
     Submit a new prompt execution (non-blocking).
 
@@ -541,7 +539,7 @@ async def submit_prompt(request: SubmitPromptRequest, _: bool = Depends(require_
 
 
 @app.get("/api/prompts/{prompt_id}")
-async def get_prompt(prompt_id: str, _: bool = Depends(require_api_key)):
+async def get_prompt(prompt_id: str, _: None = require_api_key):
     """
     Get prompt execution status and result.
 
@@ -584,7 +582,7 @@ async def get_prompt(prompt_id: str, _: bool = Depends(require_api_key)):
 
 
 @app.get("/api/prompts")
-async def list_prompts(limit: int = 50, _: bool = Depends(require_api_key)):
+async def list_prompts(limit: int = 50, _: None = require_api_key):
     """
     List recent prompt executions.
 
@@ -619,7 +617,7 @@ async def list_prompts(limit: int = 50, _: bool = Depends(require_api_key)):
 # --- Legacy Job Endpoints (backward compatibility) ---
 
 @app.get("/api/agents")
-async def list_agents(_: bool = Depends(require_api_key)):
+async def list_agents(_: None = require_api_key):
     """
     List registered agents.
 
@@ -652,7 +650,7 @@ async def list_agents(_: bool = Depends(require_api_key)):
 
 
 @app.get("/api/agents/{agent_name}/chat")
-async def chat_with_agent(agent_name: str, request: AgentChatRequest, _: bool = Depends(require_api_key)):
+async def chat_with_agent(agent_name: str, request: AgentChatRequest, _: None = require_api_key):
     """
     Send a message to an agent.
 
@@ -701,7 +699,7 @@ async def chat_with_agent(agent_name: str, request: AgentChatRequest, _: bool =
 
 
 @app.post("/api/agents/{agent_name}/batch")
-async def batch_submit_tasks(agent_name: str, request: BatchTasksRequest, _: bool = Depends(require_api_key)):
+async def batch_submit_tasks(agent_name: str, request: BatchTasksRequest, _: None = require_api_key):
     """
     Submit multiple tasks to an agent's queue in parallel.
     
@@ -817,7 +815,7 @@ async def batch_submit_tasks(agent_name: str, request: BatchTasksRequest, _: boo
 
 
 @app.post("/api/batches/{batch_id}/add-tasks")
-async def add_tasks_to_batch(batch_id: str, request: AddTasksToBatchRequest, _: bool = Depends(require_api_key)):
+async def add_tasks_to_batch(batch_id: str, request: AddTasksToBatchRequest, _: None = require_api_key):
     """
     Add more tasks to an existing batch.
     
@@ -906,7 +904,7 @@ async def add_tasks_to_batch(batch_id: str, request: AddTasksToBatchRequest, _:
 
 
 @app.get("/api/batches/{batch_id}")
-async def get_batch(batch_id: str, _: bool = Depends(require_api_key)):
+async def get_batch(batch_id: str, _: None = require_api_key):
     """Get batch metadata by ID."""
     batch = database.get_batch(batch_id)
     if not batch:
@@ -915,14 +913,14 @@ async def get_batch(batch_id: str, _: bool = Depends(require_api_key)):
 
 
 @app.get("/api/batches")
-async def list_batches(limit: int = 50, _: bool = Depends(require_api_key)):
+async def list_batches(limit: int = 50, _: None = require_api_key):
     """List recent batches."""
     batches = database.list_batches(limit=limit)
     return {"batches": batches, "limit": limit}
 
 
 @app.get("/api/agents/{agent_name}/tools")
-async def get_agent_tools(agent_name: str, _: bool = Depends(require_api_key)):
+async def get_agent_tools(agent_name: str, _: None = require_api_key):
     """
     Get detailed tool information for a specific agent.
 
@@ -1024,7 +1022,7 @@ async def get_agent_tools(agent_name: str, _: bool = Depends(require_api_key)):
 
 
 @app.get("/api/responses/{task_id}/resolved")
-async def get_resolved_response(task_id: str, _: bool = Depends(require_api_key)):
+async def get_resolved_response(task_id: str, _: None = require_api_key):
     """
     Resolve and return a task response. If the response was offloaded to storage,
     this endpoint fetches the full payload from MinIO/S3 and returns it.
@@ -1116,7 +1114,7 @@ async def get_resolved_response(task_id: str, _: bool = Depends(require_api_key)
 @app.get("/api/traces")
 async def list_traces(
     job_id: str | None = None,
-    _: bool = Depends(require_api_key),
+    _: None = require_api_key,
     agent_name: str | None = None,
     limit: int = 100,
 ):
@@ -1135,7 +1133,7 @@ async def list_traces(
 
 
 @app.get("/api/traces/grouped")
-async def get_grouped_traces(limit: int = 50, _: bool = Depends(require_api_key)):
+async def get_grouped_traces(limit: int = 50, _: None = require_api_key):
     """
     Get traces grouped by job_id.
     
@@ -1186,7 +1184,7 @@ async def get_grouped_traces(limit: int = 50, _: bool = Depends(require_api_key)
 
 
 @app.get("/api/traces/{trace_id}")
-async def get_trace(trace_id: str, _: bool = Depends(require_api_key)):
+async def get_trace(trace_id: str, _: None = require_api_key):
     """Get a single trace by id with full payload."""
     try:
         trace = database.get_trace(trace_id)
@@ -1201,7 +1199,7 @@ async def get_trace(trace_id: str, _: bool = Depends(require_api_key)):
 
 
 @app.get("/api/metrics")
-async def get_metrics(_: bool = Depends(require_api_key)):
+async def get_metrics(_: None = require_api_key):
     """
     Get system metrics.
 
@@ -1231,7 +1229,7 @@ async def get_metrics(_: bool = Depends(require_api_key)):
 # --- Container Logs Endpoints ---
 
 @app.get("/api/logs/containers")
-async def list_containers(_: bool = Depends(require_api_key)):
+async def list_containers(_: None = require_api_key):
     """
     List all Docker containers (project-agnostic).
     
@@ -1300,7 +1298,7 @@ async def list_containers(_: bool = Depends(require_api_key)):
 @app.get("/api/logs/containers/{container_name}")
 async def get_container_logs(
     container_name: str,
-    _: bool = Depends(require_api_key),
+    _: None = require_api_key,
     tail: int = 100,
     since: str | None = None,
     timestamps: bool = True
@@ -2087,7 +2085,7 @@ async def websocket_batch_traces(websocket: WebSocket, batch_id: str):
 
 
 @app.post("/api/prompts/{prompt_id}/cancel", response_model=CancelPromptResponse)
-async def cancel_prompt(prompt_id: str, _: bool = Depends(require_api_key)):
+async def cancel_prompt(prompt_id: str, _: None = require_api_key):
         """Request cancellation of a running prompt. This sets a cancel flag and updates status."""
         try:
             # Signal cancel to runtime via message bus
